# notice

Le bandeau d’information importante permet aux utilisateurs de voir ou d’accéder à une information importante et temporaire.

## Dépendances
```shell
notice
└─ core
└─ button
```

## Utilisation
Afin d’utiliser le composant `notice`, il est nécessaire d’ajouter les fichiers de styles et de scripts présents dans le dossier dist dans l'ordre suivant :\n
```html
<html>
  <head>
    <link href="css/core/core.min.css" rel="stylesheet">
    <link href="css/button/button.min.css" rel="stylesheet">
    <link href="css/notice/notice.min.css" rel="stylesheet">
  </head>
  <body>
  </body>
</html>
```

## Documentation

Consulter [la documentation](https://www.systeme-de-design.gouv.fr/elements-d-interface/composants/bandeau-d-information-importante) sur le module Bandeau d'information importante